@@ -8,6 +8,8 @@ from faker import Faker
 from faker.providers.person.ar_AA import Provider as ArProvider
 from faker.providers.person.az_AZ import Provider as AzAzProvider
 from faker.providers.person.cs_CZ import Provider as CsCZProvider
+from faker.providers.person.de_AT import Provider as DeAtProvider
+from faker.providers.person.de_LI import Provider as DeLiProvider
 from faker.providers.person.en import Provider as EnProvider
 from faker.providers.person.en_GB import Provider as EnGBProvider
 from faker.providers.person.en_IE import Provider as EnIEProvider
@@ -20,6 +22,7 @@ from faker.providers.person.et_EE import Provider as EtEEProvider
 from faker.providers.person.fi_FI import Provider as FiProvider
 from faker.providers.person.fr_BE import Provider as FrBEProvider
 from faker.providers.person.ga_IE import Provider as GaIEProvider
+from faker.providers.person.gu_IN import Provider as GuINProvider
 from faker.providers.person.he_IL import Provider as HeILProvider
 from faker.providers.person.hi_IN import Provider as HiINProvider
 from faker.providers.person.hy_AM import Provider as HyAmProvider
@@ -39,6 +42,7 @@ from faker.providers.person.ta_IN import Provider as TaINProvider
 from faker.providers.person.th_TH import Provider as ThThProvider
 from faker.providers.person.uk_UA import Provider as UkUAProvider
 from faker.providers.person.uk_UA import translit as UkUATranslit
+from faker.providers.person.uz_UZ import Provider as UzUzProvider
 from faker.providers.person.vi_VN import Provider as ViVNProvider
 from faker.providers.person.yo_NG import Provider as YoNGProvider
 from faker.providers.person.zh_CN import Provider as ZhCNProvider
@@ -208,6 +212,92 @@ class TestCsCZ(unittest.TestCase):
         assert last_name in CsCZProvider.last_names_female
 
 
+class TestDeAt(unittest.TestCase):
+    """Tests person in the de_AT locale"""
+
+    def setUp(self):
+        self.fake = Faker("de_AT")
+        Faker.seed(0)
+
+    def test_academic_prefix(self):
+        academic_prefix = self.fake.academic_prefix()
+        assert isinstance(academic_prefix, str)
+        assert academic_prefix in DeAtProvider.academic_prefixes
+
+    def test_academic_suffix(self):
+        academic_suffix = self.fake.academic_suffix()
+        assert isinstance(academic_suffix, str)
+        assert academic_suffix in DeAtProvider.academic_suffixes
+
+    def test_first_name(self):
+        first_name = self.fake.first_name()
+        assert isinstance(first_name, str)
+        assert first_name in DeAtProvider.first_names
+
+    def test_first_name_female(self):
+        name_female = self.fake.first_name_female()
+        assert isinstance(name_female, str)
+        assert name_female in DeAtProvider.first_names_female
+
+    def test_first_name_male(self):
+        name_male = self.fake.first_name_male()
+        assert isinstance(name_male, str)
+        assert name_male in DeAtProvider.first_names_male
+
+    def test_first_name_nonbinary(self):
+        name_nonbinary = self.fake.first_name_nonbinary()
+        assert isinstance(name_nonbinary, str)
+        assert name_nonbinary in DeAtProvider.first_names
+
+    def test_last_name(self):
+        last_name = self.fake.last_name()
+        assert isinstance(last_name, str)
+        assert last_name in DeAtProvider.last_names
+
+    def test_prefix(self):
+        prefix = self.fake.prefix()
+        assert isinstance(prefix, str)
+        assert prefix in DeAtProvider.prefixes
+
+    def test_prefix_female(self):
+        prefix_female = self.fake.prefix_female()
+        assert isinstance(prefix_female, str)
+        assert prefix_female in DeAtProvider.prefixes_female
+
+    def test_prefix_male(self):
+        prefix_male = self.fake.prefix_male()
+        assert isinstance(prefix_male, str)
+        assert prefix_male in DeAtProvider.prefixes_male
+
+    def test_prefix_nonbinary(self):
+        prefix_nonbinary = self.fake.prefix_nonbinary()
+        assert isinstance(prefix_nonbinary, str)
+        assert prefix_nonbinary in DeAtProvider.prefixes
+
+
+class TestDeLi(unittest.TestCase):
+    """Tests person in the de_LI locale"""
+
+    def setUp(self):
+        self.fake = Faker("de_LI")
+        Faker.seed(0)
+
+    def test_first_name(self):
+        first_name = self.fake.first_name()
+        assert isinstance(first_name, str)
+        assert first_name in DeLiProvider.first_names
+
+    def test_first_name_female(self):
+        name_female = self.fake.first_name_female()
+        assert isinstance(name_female, str)
+        assert name_female in DeLiProvider.first_names_female
+
+    def test_first_name_male(self):
+        name_male = self.fake.first_name_male()
+        assert isinstance(name_male, str)
+        assert name_male in DeLiProvider.first_names_male
+
+
 class TestEn(unittest.TestCase):
     """Tests person in the en locale"""
 
@@ -673,6 +763,68 @@ class TestGaIE(TestEnIE):
         Faker.seed(0)
 
 
+class TestGuIN(unittest.TestCase):
+    """Tests person in the gu_IN locale"""
+
+    def setUp(self):
+        self.fake = Faker("gu_IN")
+        Faker.seed(0)
+
+    """Verify that gender specific names are set correctly"""
+
+    def test_first_name(self):
+        name = self.fake.first_name()
+        self.assertIsInstance(name, str)
+        assert name in GuINProvider.first_names
+
+    def test_first_name_male(self):
+        name = self.fake.first_name_male()
+        self.assertIsInstance(name, str)
+        assert name in GuINProvider.first_names_male
+
+    def test_first_name_female(self):
+        name = self.fake.first_name_female()
+        self.assertIsInstance(name, str)
+        assert name in GuINProvider.first_names_female
+
+    def test_last_name(self):
+        last_name = self.fake.last_name()
+        self.assertIsInstance(last_name, str)
+        assert last_name in GuINProvider.last_names
+
+    def test_name(self):
+        name = self.fake.name().split()
+        assert all(isinstance(n, str) for n in name)
+        if len(name) == 3:
+            assert all(
+                [
+                    name[0] in GuINProvider.prefixes,
+                    name[1] in GuINProvider.first_names,
+                    name[2] in GuINProvider.last_names,
+                ]
+            )
+        else:
+            assert name[0] in GuINProvider.first_names
+            assert name[-1] in GuINProvider.last_names
+
+    """Verify that gender specific prefixes are set correctly"""
+
+    def test_prefix(self):
+        prefix = self.fake.prefix()
+        self.assertIsInstance(prefix, str)
+        assert prefix in GuINProvider.prefixes
+
+    def test_prefix_female(self):
+        prefix = self.fake.prefix_female()
+        self.assertIsInstance(prefix, str)
+        assert prefix in GuINProvider.prefixes_female
+
+    def test_prefix_male(self):
+        prefix = self.fake.prefix_male()
+        self.assertIsInstance(prefix, str)
+        assert prefix in GuINProvider.prefixes_male
+
+
 class TestHeIL(unittest.TestCase):
     """Tests person in the he_IL locale."""
 
@@ -1214,11 +1366,6 @@ class TestRuRU(unittest.TestCase):
         language_name = self.fake.language_name()
         assert language_name in RuProvider.language_names
 
-    def test_passport_owner(self):
-        surname, given_name = self.fake.passport_owner()
-        assert surname in RuProvider.last_names
-        assert given_name in RuProvider.first_names
-
 
 class TestSvSE(unittest.TestCase):
     def setUp(self):
@@ -1851,5 +1998,32 @@ class TestZuZa(unittest.TestCase):
             raise AssertionError("Invalid number of name parts. Expected 2 or 3.")
 
 
+class TestUzUz(unittest.TestCase):
+    def setUp(self):
+        self.fake = Faker("uz_UZ")
+        Faker.seed(0)
+        self.provider = UzUzProvider
+
+    def test_male_first_names(self):
+        for _ in range(100):
+            res = self.fake.first_name_male()
+            assert res in self.provider.first_names_male
+
+    def test_female_first_names(self):
+        for _ in range(100):
+            res = self.fake.first_name_female()
+            assert res in self.provider.first_names_female
+
+    def test_male_last_names(self):
+        for _ in range(100):
+            res = self.fake.last_name_male()
+            assert res in self.provider.last_names_male
+
+    def test_female_last_names(self):
+        for _ in range(100):
+            res = self.fake.last_name_female()
+            assert res in self.provider.last_names_female
+
+
 if __name__ == "__main__":
     unittest.main()
